package com.xk72.charles.gui.settings;

import com.xk72.charles.CharlesContext;
import com.xk72.charles.config.UserInterfaceConfiguration;
import com.xk72.charles.gui.lib.FormUtils;
import com.xk72.charles.gui.settings.SettingsPanel;
import com.xk72.charles.gui.settings.YyWX;
import java.awt.GraphicsEnvironment;
import java.awt.SystemTray;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Iterator;
import javax.swing.JCheckBox;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;

public class UISettingsPanel extends SettingsPanel {

   private final JComboBox cFont;
   private final JComboBox cFontSize;
   private final JCheckBox bShowTrayIcon = new JCheckBox(com.xk72.charles.macos.nnsC.FwRs()?"在菜单栏中显示Charles图标":"显示系统托盘图标");
   private final JCheckBox bMinimiseToTray = new JCheckBox("最小化到系统托盘");
   private final JCheckBox bShowMemoryUsage = new JCheckBox("显示内存使用情况");
   private final JCheckBox bEnableHotkeys = new JCheckBox("启用全局热键");
   private final JCheckBox bAlwaysOnTop = new JCheckBox("Charles 窗口始终位于顶部");
   private final JCheckBox bHighlightTreeChanges = new JCheckBox("突出显示结构视图中的更改");


   public UISettingsPanel() {
      super(CharlesContext.getInstance().getBundle().getString("settings.ui.name"));
      this.setHelp(this.ctx.getBundle().getString("settings.ui.help"));
      UserInterfaceConfiguration var1 = this.ctx.getConfiguration().getUserInterfaceConfiguration();
      String[] var2 = FwRs((String[])GraphicsEnvironment.getLocalGraphicsEnvironment().getAvailableFontFamilyNames());
      this.cFont = new JComboBox(var2);
      this.cFont.insertItemAt("默认", 0);
      this.cFont.setSelectedIndex(0);
      if(var1.getDisplayFont() != null) {
         this.cFont.setSelectedItem(var1.getDisplayFont());
      }

      this.cFontSize = new JComboBox();
      this.cFontSize.addItem("默认");

      for(int var3 = 9; var3 <= 24; ++var3) {
         this.cFontSize.addItem(Integer.valueOf(var3));
      }

      if(var1.getDisplayFontSize() != null) {
         this.cFontSize.setSelectedItem(var1.getDisplayFontSize());
      }

      this.bShowTrayIcon.setSelected(var1.isShowTrayIcon());
      this.bMinimiseToTray.setSelected(var1.isMinimiseToTray());
      this.bMinimiseToTray.setEnabled(this.bShowTrayIcon.isSelected());
      this.bShowTrayIcon.addChangeListener(new YyWX(this));
      this.bShowMemoryUsage.setSelected(var1.isShowMemoryUsage());
      this.bEnableHotkeys.setSelected(var1.isEnableHotkeys());
      this.bAlwaysOnTop.setSelected(var1.isAlwaysOnTop());
      this.bHighlightTreeChanges.setSelected(var1.isHighlightTreeChanges());
      JPanel var4;
      (var4 = new JPanel(FormUtils.eOaK())).add(new JLabel("显示字体:"));
      var4.add(this.cFont);
      var4.add(new JLabel("显示字体大小:"));
      var4.add(this.cFontSize);
      FormUtils.FwRs(var4);
      if(SystemTray.isSupported()) {
         var4.add(this.bShowTrayIcon, "skip");
      }

      if(com.xk72.charles.win32.dqaG.FwRs()) {
         var4.add(this.bMinimiseToTray, "skip");
         var4.add(this.bEnableHotkeys, "skip");
      }

      if(CharlesContext.getJavaVersion() >= 15) {
         var4.add(this.bAlwaysOnTop, "skip");
      }

      var4.add(this.bHighlightTreeChanges, "skip");
      var4.add(this.bShowMemoryUsage, "skip");
      this.add(var4);
   }

   private static String[] FwRs(String[] var0) {
      ArrayList var3;
      Iterator var1 = (var3 = new ArrayList(Arrays.asList(var0))).iterator();

      while(var1.hasNext()) {
         if(((String)var1.next()).startsWith(".System")) {
            var1.remove();
         }
      }

      return (String[])var3.toArray(new String[var3.size()]);
   }

   public static void main(String[] var0) {
      (new UISettingsPanel()).test();
   }

   public boolean save() {
      UserInterfaceConfiguration var1 = this.ctx.getConfiguration().getUserInterfaceConfiguration();
      String var2 = this.cFont.getSelectedItem().toString();
      Integer var3 = this.cFontSize.getSelectedItem() instanceof Integer?(Integer)this.cFontSize.getSelectedItem():null;
      boolean var4 = !FwRs(var1.getDisplayFont(), var2) || !FwRs(var1.getDisplayFontSize(), var3);
      var1.setDisplayFont(var2);
      var1.setDisplayFontSize(var3);
      if(var4) {
         this.ctx.info("显示字体更改", "请重新启动charles以完成显示字体更改的应用程序.");
      }

      var1.setShowTrayIcon(this.bShowTrayIcon.isSelected());
      var1.setMinimiseToTray(this.bMinimiseToTray.isSelected());
      var1.setShowMemoryUsage(this.bShowMemoryUsage.isSelected());
      var1.setEnableHotkeys(this.bEnableHotkeys.isSelected());
      var1.setAlwaysOnTop(this.bAlwaysOnTop.isSelected());
      var1.setHighlightTreeChanges(this.bHighlightTreeChanges.isSelected());
      return true;
   }

   private static boolean FwRs(Object var0, Object var1) {
      return var0 == var1 || var0 != null && var1 != null && var0.equals(var1);
   }

   // $FF: synthetic method
   static JCheckBox FwRs(UISettingsPanel var0) {
      return var0.bShowTrayIcon;
   }

   // $FF: synthetic method
   static JCheckBox GSXJ(UISettingsPanel var0) {
      return var0.bMinimiseToTray;
   }
}
